@@ -2,8 +2,8 @@ from typing import Iterator, Set, Tuple
 
 from grimp import build_graph
 from grimp.application.ports.graph import AbstractImportGraph
-
-from networkx.exception import NodeNotFound
+from grimp.exceptions import ModuleNotPresent
+from networkx.exception import NodeNotFound  # type: ignore[import]
 
 from .interfaces import Tree
 
@@ -21,19 +21,17 @@ class GrimpTree(Tree):
             yield module
             yield from self.graph.find_descendants(module)
 
-    def find_import_chain(self, importer: str, imported: str) -> Tuple[str, ...]:
+    def find_chains(self, importer: str, imported: str) -> Iterator[Tuple[str, ...]]:
         try:
-            chain = self.graph.find_shortest_chain(importer, imported)
+            yield from self.graph.find_all_simple_chains(importer, imported)
+        except ModuleNotPresent:
+            pass
+
+    def find_upstream_modules(self, module: str) -> Set[str]:
+        try:
+            return self.graph.find_upstream_modules(module)
         except NodeNotFound:
-            chain = None
-
-        if chain is not None:
-            return chain
-
-        return ()
-
-    def find_imported_modules(self, module: str) -> Set[str]:
-        return self.graph.find_upstream_modules(module)
+            return set()
 
 
 def new_grimp_tree(*modules: str) -> Tree:
